==> S2.0.7.jar: seasar2/src/org/seasar/extension/jdbc/types/ValueTypes.java <==
package org.seasar.extension.jdbc.types;

import java.math.BigDecimal;
import java.sql.Timestamp;
import java.sql.Types;
import java.util.Calendar;
import java.util.HashMap;
import java.util.Map;

import org.seasar.extension.jdbc.ValueType;


public final class ValueTypes {

	public final static ValueType STRING = new StringType();
	public final static ValueType SHORT = new ShortType();
	public final static ValueType INTEGER = new IntegerType();
	public final static ValueType LONG = new LongType();
	public final static ValueType FLOAT = new FloatType();
	public final static ValueType DOUBLE = new DoubleType();
	public final static ValueType BIGDECIMAL = new BigDecimalType();
	public final static ValueType TIMESTAMP = new TimestampType();
	public final static ValueType BINARY = new BinaryType();
	public final static ValueType OBJECT = new ObjectType();
	public final static ValueType NULL = new NullType();

	private static Map types_ = new HashMap();

	static {
		registerValueType(String.class, STRING);
		registerValueType(short.class, SHORT);
		registerValueType(Short.class, SHORT);
		registerValueType(int.class, INTEGER);
		registerValueType(Integer.class, INTEGER);
		registerValueType(long.class, LONG);
		registerValueType(Long.class, LONG);
		registerValueType(float.class, FLOAT);
		registerValueType(Float.class, FLOAT);
		registerValueType(double.class, DOUBLE);
		registerValueType(Double.class, DOUBLE);
		registerValueType(BigDecimal.class, BIGDECIMAL);
		registerValueType(Timestamp.class, TIMESTAMP);
		registerValueType(java.sql.Date.class, TIMESTAMP);
		registerValueType(java.util.Date.class, TIMESTAMP);
		registerValueType(Calendar.class, TIMESTAMP);
		registerValueType(new byte[0].getClass(), BINARY);
	}

	private ValueTypes() {
	}
	
	public static void registerValueType(Class clazz, ValueType valueType) {
		synchronized (types_) {
			types_.put(clazz, valueType);
		}
	}

	public static ValueType getValueType(Object obj) {
		if (obj == null) {
			return NULL;
		}
		return getValueType(obj.getClass());
	}

	public static ValueType getValueType(Class clazz) {
		ValueType valueType = getValueType0(clazz);
		if (valueType != null) {
			return valueType;
		}
		return OBJECT;
	}
	
	private static ValueType getValueType0(Class clazz) {
		synchronized (types_) {
			return (ValueType) types_.get(clazz);
		}
	}

	public static ValueType getValueType(int type) {
		switch (type) {
			case Types.TINYINT :
			case Types.SMALLINT :
				return SHORT;
			case Types.INTEGER :
				return INTEGER;
			case Types.BIGINT :
				return LONG;
			case Types.REAL :
			case Types.FLOAT :
				return FLOAT;
			case Types.DOUBLE :
				return DOUBLE;
			case Types.DECIMAL :
			case Types.NUMERIC :
				return BIGDECIMAL;
			case Types.DATE :
			case Types.TIME :
			case Types.TIMESTAMP :
				return TIMESTAMP;
			case Types.BINARY :
			case Types.VARBINARY :
			case Types.LONGVARBINARY :
				return BINARY;
			case Types.CHAR :
			case Types.LONGVARCHAR :
			case Types.VARCHAR :
				return STRING;
			default :
				return OBJECT;
		}
	}
}

==> S2.0.9.jar: seasar2/src/org/seasar/extension/jdbc/types/ValueTypes.java <==
package org.seasar.extension.jdbc.types;

import java.math.BigDecimal;
import java.sql.Timestamp;
import java.sql.Types;
import java.util.Calendar;
import java.util.HashMap;
import java.util.Map;

import org.seasar.extension.jdbc.ValueType;


public final class ValueTypes {

	public final static ValueType STRING = new StringType();
	public final static ValueType SHORT = new ShortType();
	public final static ValueType INTEGER = new IntegerType();
	public final static ValueType LONG = new LongType();
	public final static ValueType FLOAT = new FloatType();
	public final static ValueType DOUBLE = new DoubleType();
	public final static ValueType BIGDECIMAL = new BigDecimalType();
	public final static ValueType TIME = new TimeType();
	public final static ValueType SQLDATE = new SqlDateType();
	public final static ValueType TIMESTAMP = new TimestampType();
	public final static ValueType BINARY = new BinaryType();
	public final static ValueType OBJECT = new ObjectType();
	public final static ValueType NULL = new NullType();

	private static Map types_ = new HashMap();

	static {
		registerValueType(String.class, STRING);
		registerValueType(short.class, SHORT);
		registerValueType(Short.class, SHORT);
		registerValueType(int.class, INTEGER);
		registerValueType(Integer.class, INTEGER);
		registerValueType(long.class, LONG);
		registerValueType(Long.class, LONG);
		registerValueType(float.class, FLOAT);
		registerValueType(Float.class, FLOAT);
		registerValueType(double.class, DOUBLE);
		registerValueType(Double.class, DOUBLE);
		registerValueType(BigDecimal.class, BIGDECIMAL);
		registerValueType(java.sql.Date.class, SQLDATE);
		registerValueType(java.sql.Time.class, TIME);
		registerValueType(java.util.Date.class, TIMESTAMP);
		registerValueType(Timestamp.class, TIMESTAMP);
		registerValueType(Calendar.class, TIMESTAMP);
		registerValueType(new byte[0].getClass(), BINARY);
	}

	private ValueTypes() {
	}
	
	public static void registerValueType(Class clazz, ValueType valueType) {
		synchronized (types_) {
			types_.put(clazz, valueType);
		}
	}

	public static ValueType getValueType(Object obj) {
		if (obj == null) {
			return NULL;
		}
		return getValueType(obj.getClass());
	}

	public static ValueType getValueType(Class clazz) {
		ValueType valueType = getValueType0(clazz);
		if (valueType != null) {
			return valueType;
		}
		return OBJECT;
	}
	
	private static ValueType getValueType0(Class clazz) {
		synchronized (types_) {
			return (ValueType) types_.get(clazz);
		}
	}

	public static ValueType getValueType(int type) {
		switch (type) {
			case Types.TINYINT :
			case Types.SMALLINT :
				return SHORT;
			case Types.INTEGER :
				return INTEGER;
			case Types.BIGINT :
				return LONG;
			case Types.REAL :
			case Types.FLOAT :
				return FLOAT;
			case Types.DOUBLE :
				return DOUBLE;
			case Types.DECIMAL :
			case Types.NUMERIC :
				return BIGDECIMAL;
			case Types.DATE :
			case Types.TIME :
			case Types.TIMESTAMP :
				return TIMESTAMP;
			case Types.BINARY :
			case Types.VARBINARY :
			case Types.LONGVARBINARY :
				return BINARY;
			case Types.CHAR :
			case Types.LONGVARCHAR :
			case Types.VARCHAR :
				return STRING;
			default :
				return OBJECT;
		}
	}
}
